==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d3/d91/viewport__func_8h.js <==
var viewport__func_8h =
[
    [ "AddChildSpriteScreen", "d3/d91/viewport__func_8h.html#ac5e4ef44318edb11e29b74455555c079", null ],
    [ "AddSortableSpriteToDraw", "d3/d91/viewport__func_8h.html#a43bc39df4dc4da39c6f9aca08367674e", null ],
    [ "DeleteWindowViewport", "d3/d91/viewport__func_8h.html#a3952cde50ce9376e31cf877f6fa57292", null ],
    [ "DoZoomInOutWindow", "d3/d91/viewport__func_8h.html#adaa371fce2b46799616f97226d298105", null ],
    [ "DrawGroundSprite", "d3/d91/viewport__func_8h.html#ad761d12f3dc463062425a5f6c5f6da71", null ],
    [ "DrawGroundSpriteAt", "d3/d91/viewport__func_8h.html#a3c33361b88c2b29f6e21c06d56ad5715", null ],
    [ "EndSpriteCombine", "d3/d91/viewport__func_8h.html#aac1df6720caa486463739a8fe8da764c", null ],
    [ "GetTileBelowCursor", "d3/d91/viewport__func_8h.html#ae710b4538c08b15432d3b437fdf419a1", null ],
    [ "GetTileZoomCenterWindow", "d3/d91/viewport__func_8h.html#a1dab4656b4b3819b76a072b4763edfeb", null ],
    [ "GetViewportStationMiddle", "d3/d91/viewport__func_8h.html#a91fc0b192cae49cd914df17273ea3ec8", null ],
    [ "HandleViewportClicked", "d3/d91/viewport__func_8h.html#a4e5c40700bd72360e6d7cb7ab0dc664b", null ],
    [ "HandleZoomMessage", "d3/d91/viewport__func_8h.html#a20d47589cae647e248a7fa60d9035b64", null ],
    [ "InitializeWindowViewport", "d3/d91/viewport__func_8h.html#aa2b5a3d1d1334ec916552c1e803938d8", null ],
    [ "IsPtInWindowViewport", "d3/d91/viewport__func_8h.html#ab0f9236353b1eb294f8ad26918074092", null ],
    [ "MarkAllViewportsDirty", "d5/d48/group__dirty.html#ga2fa66f02f9999c0a0c5e0b54edf51361", null ],
    [ "MarkTileDirtyByTile", "d5/d48/group__dirty.html#gaa346326c6d007e24cfc39b5eaaae0409", null ],
    [ "MarkTileDirtyByTile", "d5/d48/group__dirty.html#ga4f45eab7a8f9bd138f2a6f6089c63b75", null ],
    [ "MaxZoomInOut", "d3/d91/viewport__func_8h.html#afd68e5901ce4b5763c54f87a35d72ea6", null ],
    [ "OffsetGroundSprite", "d3/d91/viewport__func_8h.html#a1616e10da13f6ce63387332acdafb984", null ],
    [ "RebuildViewportOverlay", "d3/d91/viewport__func_8h.html#a158da2750d65024f860d17973b92c2fa", null ],
    [ "ScrollMainWindowTo", "d3/d91/viewport__func_8h.html#a957ece99d2db232c0e404406ac45a312", null ],
    [ "ScrollMainWindowToTile", "d3/d91/viewport__func_8h.html#a08c16e9f49914dc43c2d721a7ff65fb2", null ],
    [ "ScrollWindowTo", "d3/d91/viewport__func_8h.html#aa724939b1f9faa5eb2d4acd19a4edf00", null ],
    [ "ScrollWindowToTile", "d3/d91/viewport__func_8h.html#aedc9cefc08a2e9e9c519748c823b2ca2", null ],
    [ "SetRedErrorSquare", "d3/d91/viewport__func_8h.html#a8ce64be63f39e5c7864b8db4732f02fe", null ],
    [ "SetSelectionRed", "d3/d91/viewport__func_8h.html#a4953d9a7ebe79a003f0fdd73d9a4ab9f", null ],
    [ "SetTileSelectBigSize", "d3/d91/viewport__func_8h.html#a2528e962cf5505d31e5e4a2545807cc6", null ],
    [ "SetTileSelectSize", "d3/d91/viewport__func_8h.html#a0e75ffff0aebbe42ac47cd491f2a4697", null ],
    [ "StartSpriteCombine", "d3/d91/viewport__func_8h.html#a388154f13b37f0c00fa8d1b74efab445", null ],
    [ "TranslateXYToTileCoord", "d3/d91/viewport__func_8h.html#af46f6ea033c9da4cc41632ab2fbd82d4", null ],
    [ "UpdateAllVirtCoords", "d3/d91/viewport__func_8h.html#ab60241e738333d51c3a55787f35c7d9b", null ],
    [ "UpdateViewportPosition", "d3/d91/viewport__func_8h.html#a70eeeb20f55f90d6c578b62fee2cab7c", null ],
    [ "ViewportAddString", "d3/d91/viewport__func_8h.html#a6a3f9980d11aad3b22b11665803b1040", null ],
    [ "ViewportDoDraw", "d3/d91/viewport__func_8h.html#a4ee69655771142ed52ae2cad383cbcf8", null ],
    [ "ZoomInOrOutToCursorWindow", "d3/d91/viewport__func_8h.html#ad33aa4a7c820c1165c9265e2ef32041b", null ],
    [ "_tile_fract_coords", "d3/d91/viewport__func_8h.html#ab3497b584e5afc307f0410cd93f7897e", null ],
    [ "TILE_HEIGHT_STEP", "d3/d91/viewport__func_8h.html#aefeafe8fc07d5fdbe265f4bb56cf0417", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d3/d91/viewport__func_8h.js <==
var viewport__func_8h =
[
    [ "AddChildSpriteScreen", "d3/d91/viewport__func_8h.html#ab9745d42e7cc7319c3b16f2cbee14740", null ],
    [ "AddSortableSpriteToDraw", "d3/d91/viewport__func_8h.html#a0029282de0786b5f5d8d9d27b62b2792", null ],
    [ "ClearAllCachedNames", "d3/d91/viewport__func_8h.html#aedc78dd0f8a93970999eff5d5ffd5273", null ],
    [ "DeleteWindowViewport", "d3/d91/viewport__func_8h.html#a3952cde50ce9376e31cf877f6fa57292", null ],
    [ "DoZoomInOutWindow", "d3/d91/viewport__func_8h.html#adaa371fce2b46799616f97226d298105", null ],
    [ "DrawGroundSprite", "d3/d91/viewport__func_8h.html#a79cebcacbc21076e29f4d7c309a6d244", null ],
    [ "DrawGroundSpriteAt", "d3/d91/viewport__func_8h.html#a62e9e0b4b3804da7ed3f016a694d9bec", null ],
    [ "EndSpriteCombine", "d3/d91/viewport__func_8h.html#aac1df6720caa486463739a8fe8da764c", null ],
    [ "FixTitleGameZoom", "d3/d91/viewport__func_8h.html#a06d73d45c4871fa5dd174257b8013b2c", null ],
    [ "GetTileBelowCursor", "d3/d91/viewport__func_8h.html#ae710b4538c08b15432d3b437fdf419a1", null ],
    [ "GetTileZoomCenterWindow", "d3/d91/viewport__func_8h.html#a1dab4656b4b3819b76a072b4763edfeb", null ],
    [ "GetViewportStationMiddle", "d3/d91/viewport__func_8h.html#ab74efc871bf8744dda16f0252546534b", null ],
    [ "HandleViewportClicked", "d3/d91/viewport__func_8h.html#a4f8cde0fc6f6cf03940f19c3336f3f36", null ],
    [ "HandleZoomMessage", "d3/d91/viewport__func_8h.html#a0bbab9a663c1623c79fda9679ee45d13", null ],
    [ "InitializeWindowViewport", "d3/d91/viewport__func_8h.html#aa2b5a3d1d1334ec916552c1e803938d8", null ],
    [ "IsPtInWindowViewport", "d3/d91/viewport__func_8h.html#a5ca38479dab05800fb16b0e2a996cc61", null ],
    [ "MarkAllViewportsDirty", "d5/d48/group__dirty.html#ga0dac5613e1d024ef3e6b4777409701d2", null ],
    [ "MarkTileDirtyByTile", "d5/d48/group__dirty.html#gaa346326c6d007e24cfc39b5eaaae0409", null ],
    [ "MarkTileDirtyByTile", "d5/d48/group__dirty.html#ga4f45eab7a8f9bd138f2a6f6089c63b75", null ],
    [ "MaxZoomInOut", "d3/d91/viewport__func_8h.html#afd68e5901ce4b5763c54f87a35d72ea6", null ],
    [ "OffsetGroundSprite", "d3/d91/viewport__func_8h.html#a1616e10da13f6ce63387332acdafb984", null ],
    [ "RebuildViewportOverlay", "d3/d91/viewport__func_8h.html#a158da2750d65024f860d17973b92c2fa", null ],
    [ "ScrollMainWindowTo", "d3/d91/viewport__func_8h.html#a957ece99d2db232c0e404406ac45a312", null ],
    [ "ScrollMainWindowToTile", "d3/d91/viewport__func_8h.html#a08c16e9f49914dc43c2d721a7ff65fb2", null ],
    [ "ScrollWindowTo", "d3/d91/viewport__func_8h.html#aa724939b1f9faa5eb2d4acd19a4edf00", null ],
    [ "ScrollWindowToTile", "d3/d91/viewport__func_8h.html#aedc9cefc08a2e9e9c519748c823b2ca2", null ],
    [ "SetRedErrorSquare", "d3/d91/viewport__func_8h.html#a8ce64be63f39e5c7864b8db4732f02fe", null ],
    [ "SetSelectionRed", "d3/d91/viewport__func_8h.html#a4953d9a7ebe79a003f0fdd73d9a4ab9f", null ],
    [ "SetTileSelectBigSize", "d3/d91/viewport__func_8h.html#a2528e962cf5505d31e5e4a2545807cc6", null ],
    [ "SetTileSelectSize", "d3/d91/viewport__func_8h.html#a0e75ffff0aebbe42ac47cd491f2a4697", null ],
    [ "SetViewportCatchmentStation", "d3/d91/viewport__func_8h.html#ac75edf1b510b5ec4fb34831959622942", null ],
    [ "SetViewportCatchmentTown", "d3/d91/viewport__func_8h.html#ac8708407ab4da27e14c7b775e8b9b854", null ],
    [ "StartSpriteCombine", "d3/d91/viewport__func_8h.html#a388154f13b37f0c00fa8d1b74efab445", null ],
    [ "TranslateXYToTileCoord", "d3/d91/viewport__func_8h.html#a595e1c9c791b7c98e8ee600c8429671c", null ],
    [ "UpdateAllVirtCoords", "d3/d91/viewport__func_8h.html#ab60241e738333d51c3a55787f35c7d9b", null ],
    [ "UpdateViewportPosition", "d3/d91/viewport__func_8h.html#a70eeeb20f55f90d6c578b62fee2cab7c", null ],
    [ "ViewportAddString", "d3/d91/viewport__func_8h.html#a6a3f9980d11aad3b22b11665803b1040", null ],
    [ "ViewportDoDraw", "d3/d91/viewport__func_8h.html#a55a5245ac987290b2caa49f5fb959189", null ],
    [ "ZoomInOrOutToCursorWindow", "d3/d91/viewport__func_8h.html#ad33aa4a7c820c1165c9265e2ef32041b", null ],
    [ "_tile_fract_coords", "d3/d91/viewport__func_8h.html#ab3497b584e5afc307f0410cd93f7897e", null ],
    [ "TILE_HEIGHT_STEP", "d3/d91/viewport__func_8h.html#aefeafe8fc07d5fdbe265f4bb56cf0417", null ]
];
